;###########################################
;# Projekt: 								# 
;# 											#
;#											#
;# Taktfrequenz des AVR: 4 MHz	 			#
;# 											#
;# CS-SOFT 									#
;###########################################

.include "m8def.inc"	;Atmega8

.def temp0 = r16 	; 
.def temp1 = r17 	;
.def temp2 = r18
.def temp3 = r19 	;
.def temp4 = r20
.def cnt   = r21

;**********Auslesen des LTC1286
.equ	LTCPortX	=PortB
.equ 	LTCddrX		=DDrB
.equ	LTCpinX		=PinB

.equ	LTCCLK		=0				;Takterzeugung
.equ	LTCDat		=1				;Daten von Leitung
.equ	nCS			=2				;chipselect/shutdown

;**********SRAM
.equ 	erg_k		=	$0060			;erg_k wird bis zu 5 weiteren bytes genutzt sprich erg_k+5
.equ 	ocr2s		=	$0065			;fr T2
.equ 	ocra1h		=	$0066			;;;;;
.equ 	ocra1l		=	$0067			;;;;;;;; fr T1 A channel
.equ 	ocrb1h		=	$0068			;;;;;
.equ 	ocrb1l		=	$0069			;;;;;;;; fr T1 B channel
.equ 	icr1xh		=	$006a			;;;;;
.equ 	icr1xl		=	$006b			;;;;;;;; fr T1 ICR
.equ	hadc		=	$006c			;adc
.equ	ladc		=	$006d			;adc
.equ	eep_adrh	=	$006e			;eeprom
.equ	eep_adrl	=	$006f			;eeprom
.equ	LTC_wertH	=	$0070
.equ	LTC_wertL	=	$0071

;***************************Einsprungadressen***********************
.cseg
.org $0000
	rjmp	stack
.org $0001			;1
	reti;rjmp	INT_0
.org $0002			;2
	reti;rjmp	INT_1
.org $0003			;3
	reti;rjmp	INT_OC2
.org $0004			;4
	reti;rjmp	INT_OVF2
.org $0005			;5
	reti;rjmp	INT_ICP1
.org $0006			;6
	reti;rjmp	INT_OC1A
.org $0007			;7
	reti;rjmp	INT_OC1B
.org $0008			;8
	reti;rjmp	INT_OVF1
.org $0009			;9
	reti;rjmp	INT_OVF0

		reti		;a keine SPI Routinen

.org $000b			;b
	reti;rjmp	INT_URXC
.org $000c			;c
	reti;rjmp	INT_UDRE
.org $000d			;d
	reti;rjmp	INT_UTXC
.org $000e			;e
	reti;rjmp	adc_rdy
.org $000f			;f
	reti;rjmp	eeprom_rdy
.org $0010			;10
	reti;rjmp	ac_int

		reti		;11	keine 2wireRoutinen
		reti		;12 keine SPMRoutinen

;***************************Init mit allem drumdran*****************
stack:	ldi 		temp1,high(ramend)  ;Stackpointer festlegen
	    out 		sph, temp1
		ldi 		temp1,low(ramend)   ;Stackpointer festlegen
        out 		spl, temp1
	
		rcall		usart_init			;Usart init
		rcall		tx					;sende rdy
	
		rcall		LTC_init			;ADC-PINS init
	
		rcall		mode3_T2_init		;PWM einrichten	
		rcall		prescaler_T2_on		;Starten

start:	rcall		rx					;warte auf Zeichen 'S'
		rcall		LTC_read			;dann LTC auslesen
		rcall		out_rs232			;sende wert ber RS232
		rjmp		start

;************Daten zum PC schicken
out_rs232:
		lds			xh,LTC_werth
		lds			xl,LTC_wertL
		rcall		hex_dez
		rcall		load_Ypontr
out_rs232_2:
		ld			temp1,y+
		ori			temp1,$30
		rcall		data_transmit
		cpi			yl,erg_k+5
		brne		out_rs232_2
		ldi			temp1,'m'
		rcall		data_transmit	
		ldi			temp1,'V'
		rcall		data_transmit	
		ldi			temp1,$0D		;return
		rcall		data_transmit	;
		ldi			temp1,$0A		;
		rcall		data_transmit	;	
		ret

;Wandeln in DEZ 
hex_dez:rcall		load_Ypontr			;Speicherbereich laden	
		ldi   		cnt,$ff				;offset laden damit 0 auch erfasst wird
num_10000: 								;zehntausender
		inc   		cnt					;+1
        subi 		xl, low(10000)		;
        sbci  		xh, high(10000)		;vergleich auf >10000
        brcc  		num_10000			;ja
        subi  		xl, low(-10000)		;nein 
        sbci  		xh, high(-10000)	;subi x,-z = + quasi +10000
        st			y+,cnt				;fertig speichern
        ldi   		cnt,$ff				;siehe hex_dez nur mit anderen SUBTRAHENDEN
num_1000:								;Tausender 
		inc   		cnt
        subi  		xl, low(1000)
        sbci  		xh, high(1000)
        brcc  		num_1000
        subi  		xl, low(-1000)
        sbci  		xh, high(-1000)
        st			y+,cnt 
        ldi   		cnt,$ff
num_100:inc   		cnt					;Hunderter
        subi  		xl, low(100)
        sbci  		xh, high(100)
        brcc  		num_100
        subi  		xl, -100             
        st			y+,cnt
        ldi  		cnt,$ff
num_10:	inc   		cnt					;Zehner 
        subi  		xl, 10
        brcc  		num_10
        subi  		xl, -10
        st			y+,cnt 
	    clr   		cnt					;Einer
        add   		cnt,xl
        st			y+,cnt 
        ret

load_Ypontr:
		ldi			yh,high(erg_k)			
		ldi			yl,low(erg_k)			;speicherpunkt laden
		ret
;*************************weitere*includedata***********************
.include "zeitschleifen.asm"
.include "LTC1286.asm"
.include "rs232.asm"
;*************************ENDE**************************************
